/*
 * Copyright (C) 2002-2004 Red Hat Inc. All Rights Reserved.
 *
 * The contents of this file are subject to the CCM Public
 * License (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the
 * License at http://www.redhat.com/licenses/ccmpl.html.
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language
 * governing rights and limitations under the License.
 *
 */
package com.arsdigita.formbuilder;


// This class is an ACSObject using BigDecimals for its ids
import java.math.BigDecimal;

// This factory creates a Deditor
import com.arsdigita.bebop.form.Deditor;

// Every PersistentComponentFactory can create a Bebop Component
import com.arsdigita.bebop.Component;

// Id class used by internal constructor
import com.arsdigita.persistence.OID;
import com.arsdigita.persistence.DataObject;
import com.arsdigita.persistence.metadata.ObjectType;

// Thrown if the underlying DataObject with given id cannot be found
import com.arsdigita.domain.DataObjectNotFoundException;

// We define a process listener for adding a text area
//import com.arsdigita.bebop.event.FormProcessListener;

// ACS 5 uses Log4J for logging
import org.apache.log4j.Logger;


/**
 * This class is responsible for persisting Bebop Deditors. The Deditor
 * is saved with the save() method. To resurrect the Deditor, use the constructor
 * taking the id of the saved Deditor and then invoke createComponent().
 *
 * @author Scott Seago
 * @version $Id: //core-platform/dev/src/com/arsdigita/formbuilder/PersistentDeditor.java#8 $
 *
 */
public class PersistentDeditor extends PersistentWidget
    implements AttributeMetaDataProvider {

    public static final String versionId = "$Id: //core-platform/dev/src/com/arsdigita/formbuilder/PersistentDeditor.java#8 $ by $Author: dennis $, $DateTime: 2004/04/07 16:07:11 $";

    private static final Logger s_log =
        Logger.getLogger(PersistentDeditor.class.getName());

    /**
     * The fully qualified name of the underlying DataObject of this class.
     */
    public static final String BASE_DATA_OBJECT_TYPE =
        "com.arsdigita.formbuilder.Widget";

    // *** Constructors -------------

    /**
     * Constructor that creates a new Deditor domain object that
     * can be saved to the database later on. This class was only
     * included to make it possible to use this DomainObject with the
     * FormGenerator (to make the class JavaBean compliant). Use the constructor
     * taking a parameter name instead if possible.
     */
    public PersistentDeditor() {
        this(BASE_DATA_OBJECT_TYPE);
    }

    /**
     * Constructor that creates a new Deditor domain object that
     * can be saved to the database later on.
     */
    public PersistentDeditor(String typeName) {
        super(typeName);
    }

    public PersistentDeditor(ObjectType type) {
        super(type);
    }

    public PersistentDeditor(DataObject obj) {
        super(obj);
    }

    /**
     * Constructor that retrieves an existing Deditor domain object
     * from the database.
     *
     * @param id The object id of the Deditor domain object to retrieve
     */
    public PersistentDeditor(BigDecimal id)
        throws DataObjectNotFoundException {

        this(new OID(BASE_DATA_OBJECT_TYPE, id));
    }

    /**
     * Extending classes can use this constructor to set the sub class
     * id and object type.
     */
    public PersistentDeditor(OID oID)
        throws DataObjectNotFoundException {

        super(oID);
    }

    public static PersistentDeditor create(String parameterName) {
        PersistentDeditor t = new PersistentDeditor();
        t.setup(parameterName);
        return t;
    }

    /**
     * Create the Deditor whose persistence is managed
     * by this domain object.
     */
    public Component createComponent() {

        Deditor textArea = new Deditor(getParameterName());

        copyValuesToWidget(textArea);

        return textArea;
    }

    //*** Attribute Methods

    //*** Attribute metadata
    public AttributeMetaDataList getAttributeMetaData() {

        AttributeMetaDataList list = super.getAttributeMetaData();

        return list;
    }
}
